<?php 
ini_set('display_errors','On');
require_once($_SERVER['DOCUMENT_ROOT'].'/shine/datos/clsQuery.php');
	class clsUsuario extends Query 
	{
		var $filas = NULL;
		function __construct()  
		{
			parent::__construct();
			parent::MET_Conectar();
		}      
		
		function MET_modificarperfil($identificacion, $nombre, $apellido, $direccion, $email, $celular, $telefono)  {
			$sql = "UPDATE m_cliente SET dir_cia = \'$direccion\' ,
					mai_cia = \'$email\' ,
					tel_casa = \'$celular\' ,
					tel_movil = \'$telefono\' ,
					est_cia = \'P\' 
				  where cod_cia = \'$identificacion\' 
			";
			
			parent::__set('sql', $sql);
			$a = parent::MET_Update();
			return $a;
		} // end MET_consultaLibro	
		
		function MET_crearperfil($identificacion, $nombre, $apellido, $direccion, $email, $celular, $telefono)  {
			$sql = "insert into m_cliente SET dir_cia = \'$direccion\' ,
					mai_cia = \'$email\'  ,
					tel_casa = \'$celular\'  ,
					tel_movil = \'$telefono\' ,
				    cod_cia = \'$identificacion\',
					nom_cia = \'$nombre\',
					ape_cia = \'$apellido\',		
					est_cia = \'P\' 			
			";
				//	echo $sql;exit;
			parent::__set('sql', $sql);
			$a = parent::MET_Insert();
			return $a;
		} // end MET_consultaLibro	
		
		function MET_crearusuario($identificacion)  {
			$sql = "insert into m_usuario SET cod_cia = \'$identificacion\' ,
					nom_clave = md5(\'$identificacion\')  ,
					est_usuario = \'A\'
			";
			
			parent::__set('sql', $sql);
			$a = parent::MET_Insert();
			return $a;
		} // end MET_consultaLibro	
	
	function MET_consultarPerfil($identificacion)  {
			$sql = "
				SELECT 
				  cod_cia,
				  nom_cia, 
				  ape_cia,
				  dir_cia,
				  tel_casa,
				  tel_movil,
				  mai_cia,
				  no_cuenta,
				  nombre_banco
				FROM
				  m_cliente 
				where cod_cia =   \'$identificacion\'
			";
				
			parent::__set('sql', $sql);
			$registros = parent::MET_SelectOne();
             
			return $registros;
		} // end MET_consultaLibro		

/*
Consulta cliente
*/

		function MET_ConsultarCliente2($usuario, $tipo)  {
			
				$sql1 = "
				SELECT 	a.cod_cia, 
						a.nom_cia, 
						a.ape_cia, 
						a.dir_cia, 
						a.tel_casa, 
						a.tel_movil, 
						a.mai_cia, 
						a.cod_lider, 
						a.tip_categoria,
						a.nom_director,
						(SELECT concat(b.ape_cia,\' \',b.nom_cia) FROM m_cliente b WHERE b.cod_cia = a.cod_lider) as nom_lider
						FROM 
						m_cliente a
						WHERE a.cod_cia = \'$usuario\'
						AND a.est_cia in (\'A\',\'P\')
						and a.nom_director = \'$tipo\'
						;
				";
				
				
				parent::__set('sql', $sql1);
				$respuesta2 = parent::MET_SelectOne();
				//print_r($sql1);exit;
				return $respuesta2;	
		} // end MET_consultaLibro	

/*
Consulta cliente
*/



		
		function MET_existeusuario($usuario, $clave, $ip, $tipo)  {
			$sql = "
				SELECT 
				  cod_cia
				FROM
				  m_usuario
				WHERE cod_cia = \'$usuario\' 
				AND md5(upper(trim(\'$clave\'))) = nom_clave
				and est_usuario=\'A\' 
			";
			
			parent::__set('sql', $sql);
			$respuesta = parent::MET_SelectOne();
			if($respuesta){
				$sql1 = "
				SELECT 	a.cod_cia, 
						a.nom_cia, 
						a.ape_cia, 
						a.dir_cia, 
						a.tel_casa, 
						a.tel_movil, 
						a.mai_cia, 
						a.cod_lider, 
						a.tip_categoria,
						a.nom_director,
						(SELECT concat(b.ape_cia,\' \',b.nom_cia) FROM m_cliente b WHERE b.cod_cia = a.cod_lider) as nom_lider
						FROM 
						m_cliente a
						WHERE a.cod_cia = \'$usuario\'
						AND a.est_cia in (\'A\',\'P\')
						and a.nom_director = \'$tipo\'
						;
				";
				
				parent::__set('sql', $sql1);
				$respuesta2 = parent::MET_SelectOne();
				
			}
			if($respuesta2){
				$respuesta['razon_social']=$respuesta2['nom_cia'].' '.$respuesta2['ape_cia'];
			}
			
			if(!($respuesta['razon_social']=='')){
				
				$sql = "
				INSERT INTO t_auditoriaconexiones (cod_cia, fec_dia, nom_ip)
				values	(\'$usuario\', now(), \'$ip\')
				";
				parent::__set('sql', $sql);
				$a = parent::MET_Insert();
				return $respuesta2;
			}else{
				return false;
			}			
		} // end MET_consultaLibro	
		
		
		/* Admin*/
		function MET_existeusuarioAdmin($usuario, $clave, $ip, $tipo)  {
			$sql = "
				SELECT 
				  cod_cia
				FROM
				  m_usuario
				WHERE cod_cia = \'$usuario\' 
				AND md5(upper(trim(\'$clave\'))) = nom_clave
				and est_usuario=\'A\' 
			";
			parent::__set('sql', $sql);
			$respuesta = parent::MET_SelectOne();
			if($respuesta){
				$respuesta['razon_social']='Administrador Agrobonos';
			}
			
			if(!($respuesta['razon_social']=='')){
				
				$sql = "
				INSERT INTO t_auditoriaconexiones (cod_cia, fec_dia, nom_ip)
				values	(\'$usuario\', now(), \'$ip\')
				";
				parent::__set('sql', $sql);
				$a = parent::MET_Insert();
				return $respuesta;
			}else{
				return false;
			}			
		} // end MET_consultaLibro	
		
		/* Admin*/
		
		
		function MET_consultaConexiones($identificacion)  {
			$sql = "
				SELECT 
				   DATE_FORMAT(fec_dia,\"%d-%m-%Y\") AS fecha,
				   DATE_FORMAT(fec_dia,\"%H:%i\") AS hora,
				  nom_ip AS ip
				FROM
				  t_auditoriaconexiones 
				WHERE cod_cia = \'$identificacion\' 
				ORDER BY 1,
				  2,
				  3 
			
			";
			parent::__set('sql', $sql);
			$registros = parent::MET_Select();
			return $registros;
		} // end MET_consultaLibro
	
	function MET_fillTable($identificacion)  {
			$registros = $this->MET_consultaConexiones($identificacion);
			if (!$registros) 
			{
			$this->filas = '<tr> 
    		<td><div align="center" colspan="5"> '.$this->msj_query.'</div></td>
    				</tr>';	
			}
			else
			{
			foreach($registros as $ind => $reg) 
				{
				$this->filas .=	'
				<tr>
				<td>'.$reg['fecha'].'</td>
				<td>'.$reg['hora'].'</td>
				<td>'.$reg['ip'].'</td>
  				</tr>
				';	
				} //end foreach
			}//end if
			return $this->filas;			
		} // end MET_fillCombo*/	
		
		
		
		function MET_clavenueva($identificacion, $clave_anterior, $clave_nueva, $clave_confirma)  {
			if(!(strtoupper($clave_nueva)==strtoupper($clave_confirma))){
				return false;
			}
			if((strtoupper($clave_nueva)==strtoupper($clave_anterior))){
				return false;
			}
			$sql = "
				SELECT 
				  1 as verificado
				FROM
				  m_usuario
				WHERE cod_cia = \'$identificacion\' 
				AND md5(upper(trim(\'$clave_anterior\'))) = nom_clave
				and est_usuario=\'A\' 
			";
			parent::__set('sql', $sql);
			$respuesta = parent::MET_SelectOne();
			if(!($respuesta['verificado']==1)){
				return false;
			}
			$sql = "UPDATE m_usuario SET NOM_CLAVE = md5(upper(trim(\'$clave_nueva\')))
				  where COD_CIA = \'$identificacion\' 
				  AND md5(upper(trim(\'$clave_anterior\'))) = nom_clave
			";
			parent::__set('sql', $sql);
			$a = parent::MET_Update();
			return $a;
		} // end MET_consultaLibro	
	}//end class
?>
